pub fn is_error(
arguments: &[ValueResult],
span: Span,
) -> Result<(ValueResult, Option<ExitCode>), Error>Expand description
Returns true if the value is an error, otherwise false.
Expectes exactly one argument.
pub fn is_error(
arguments: &[ValueResult],
span: Span,
) -> Result<(ValueResult, Option<ExitCode>), Error>Returns true if the value is an error, otherwise false.
Expectes exactly one argument.